==> update4.2.14-4.4.2.tar.gz: ROOT/RouletteMaster/send_email_to_all_f_and_e.sh <==
#!/bin/bash
#===============================================================================
#
#          FILE:  send_email_to_all.sh
#
#         USAGE:  see --help
#
#   DESCRIPTION:  It sends emails to all addresses from database by reading
#		  the parameter NOTIFICATION_EMAIL_[INDEX] from configuration. 
#
#       OPTIONS:  --help - prints usage
#  REQUIREMENTS:  sqlexec.sh, send_email.sh
#          BUGS:  ---
#         NOTES:  roulette master uses this script for sending emails
#		  this script must be accessible as /RouletteMaster/send_email_to_all.sh
#        AUTHOR:  Enej Miklavčič, enej.miklavcic@gmail.com
#       COMPANY:  Freeware
#       VERSION:  1.0
#       CREATED:  12.12.2008
#      REVISION:  ---
#===============================================================================
MAX_EMAILS=10
SQL_EXE=/RouletteMaster/sqlexec.sh
SEND_EMAIL=/RouletteMaster/send_email.sh
ATTACHMENT_FOLDER="/RouletteMaster/eml_attach"

if [ "--help" = "$1" ]  ;then
    echo
    echo "Usage:"
    echo "echo \"Email body text\" | $0 \"Email Subject\""
    echo -e "\tor"
    echo "$0 \"Email Subject\" < ./EmailBodyFile.txt"
    echo
    exit 0;
fi                                
echo

if [ $# -lt 1 ]; then
    echo "Params error. Try --help for help."
    exit 1
fi

F_TEMP=`mktemp ./email_to_all.tmp_XXXX`

#read email body from pipe
cat /proc/$$/fd/0 > $F_TEMP;

if [ ! -s $F_TEMP ]; then
    echo "Pipe error. Try --help for help."
    rm $F_TEMP -rf
    exit 1
fi

if [ -f /RouletteMaster/ROULETTE_NAME ]; then
    ROULETTE_NAME=`cat /RouletteMaster/ROULETTE_NAME`
else
    ROULETTE_NAME=`echo "select RES_STR_VALUE from GET_PARAM('192.168.0.254', 'ROULETTE_NAME', 11)" | $SQL_EXE|head -6|tail -1|sed -e 's/  *$//'`
    echo $ROULETTE_NAME > /RouletteMaster/ROULETTE_NAME
fi
            
SUBJECT=$1

#naredimo bakup za attachment-e
rm $ATTACHMENT_FOLDER"_TMP" -rf
mkdir -p $ATTACHMENT_FOLDER"_TMP"
cp $ATTACHMENT_FOLDER"/" $ATTACHMENT_FOLDER"_TMP" -rfT;
#posljemo report na vse prijavljene email-e
INDEX=0
while [ $INDEX -lt $MAX_EMAILS ]; do
    let INDEX=INDEX+1
    EMAIL_ADDRESS=`echo "select RES_STR_VALUE from GET_PARAM('192.168.0.254', 'NOTIFICATION_EMAIL_$INDEX', 11)" | $SQL_EXE|grep "@"|grep "."`
    if [ -n "$EMAIL_ADDRESS" ]; then
        #echo "Sending email to $EMAIL_ADDRESS"
        cp $ATTACHMENT_FOLDER"_TMP/" $ATTACHMENT_FOLDER -rfT;
        cat $F_TEMP |$SEND_EMAIL "$SUBJECT" $EMAIL_ADDRESS "$ROULETTE_NAME"
    else
        #echo "done."
	INDEX=$MAX_EMAILS
    fi
done
rm $F_TEMP -rf
rm $ATTACHMENT_FOLDER"_TMP" -rf
rm `echo $ATTACHMENT_FOLDER"/*"` -Rf 
#mkdir $ATTACHMENT_FOLDER
#pobrišemo tudi vse tukaj, ceprav najbrz ni nicesar, samo za primer ko ni nobenega email naslova

exit 0

==> update4.4.2-4.8.5.tar.gz: ROOT/RouletteMaster/send_email_to_all_f_and_e.sh <==
#!/bin/bash
#===============================================================================
#
#          FILE:  send_email_to_all.sh
#
#         USAGE:  see --help
#
#   DESCRIPTION:  It sends emails to all addresses from database by reading
#		  the parameter NOTIFICATION_EMAIL_[INDEX] from configuration. 
#
#       OPTIONS:  --help - prints usage
#  REQUIREMENTS:  sqlexec.sh, send_email.sh
#          BUGS:  ---
#         NOTES:  roulette master uses this script for sending emails
#		  this script must be accessible as /RouletteMaster/send_email_to_all.sh
#        AUTHOR:  Enej Miklavčič, enej.miklavcic@gmail.com
#       COMPANY:  Freeware
#       VERSION:  1.0
#       CREATED:  12.12.2008
#      REVISION:  ---
#===============================================================================
MAX_EMAILS=10
SQL_EXE=/RouletteMaster/sqlexec.sh
SEND_EMAIL=/RouletteMaster/send_email.sh
ATTACHMENT_FOLDER="/RouletteMaster/eml_attach"

if [ "--help" = "$1" ]  ;then
    echo
    echo "Usage:"
    echo "echo \"Email body text\" | $0 \"Email Subject\""
    echo -e "\tor"
    echo "$0 \"Email Subject\" < ./EmailBodyFile.txt"
    echo
    exit 0;
fi                                
echo

if [ $# -lt 1 ]; then
    echo "Params error. Try --help for help."
    exit 1
fi

F_TEMP=`mktemp ./email_to_all.tmp_XXXX`

#read email body from pipe
cat /proc/$$/fd/0 > $F_TEMP;

if [ ! -s $F_TEMP ]; then
    echo "Pipe error. Try --help for help."
    rm $F_TEMP -rf
    exit 1
fi

if [ -f /RouletteMaster/ROULETTE_NAME ]; then
    ROULETTE_NAME=`cat /RouletteMaster/ROULETTE_NAME`
else
    ROULETTE_NAME=`echo "select RES_STR_VALUE from GET_PARAM('192.168.0.254', 'ROULETTE_NAME', 11);" | $SQL_EXE|head -6|tail -1|sed -e 's/  *$//'`
    echo $ROULETTE_NAME > /RouletteMaster/ROULETTE_NAME
fi
            
SUBJECT=$1

#naredimo bakup za attachment-e
rm $ATTACHMENT_FOLDER"_TMP" -rf
mkdir -p $ATTACHMENT_FOLDER"_TMP"
cp $ATTACHMENT_FOLDER"/" $ATTACHMENT_FOLDER"_TMP" -rfT;
#posljemo report na vse prijavljene email-e
INDEX=0
while [ $INDEX -lt $MAX_EMAILS ]; do
    let INDEX=INDEX+1
    EMAIL_ADDRESS=`echo "select RES_STR_VALUE from GET_PARAM('192.168.0.254', 'NOTIFICATION_EMAIL_$INDEX', 11);" | $SQL_EXE|grep "@"|grep "."`
    if [ -n "$EMAIL_ADDRESS" ]; then
        #echo "Sending email to $EMAIL_ADDRESS"
        cp $ATTACHMENT_FOLDER"_TMP/" $ATTACHMENT_FOLDER -rfT;
        cat $F_TEMP |$SEND_EMAIL "$SUBJECT" $EMAIL_ADDRESS "$ROULETTE_NAME"
    else
        #echo "done."
	INDEX=$MAX_EMAILS
    fi
done
rm $F_TEMP -rf
rm $ATTACHMENT_FOLDER"_TMP" -rf
rm `echo $ATTACHMENT_FOLDER"/*"` -Rf 
#mkdir $ATTACHMENT_FOLDER
#pobrišemo tudi vse tukaj, ceprav najbrz ni nicesar, samo za primer ko ni nobenega email naslova

exit 0
